@@ -1,5 +1,5 @@
 from functools import lru_cache
-from typing import Dict, List, Iterable, Any, Union
+from typing import Dict, List, Iterable, Any, Union, Type
 
 import numpy as np
 import numpy.typing as npt
@@ -7,12 +7,12 @@ import tensorflow as tf  # type: ignore
 
 from code_loader.contract.datasetclasses import DatasetSample, DatasetBaseHandler, InputHandler, \
     GroundTruthHandler, PreprocessResponse, VisualizerHandler, VisualizerCallableReturnType, CustomLossHandler, \
-    PredictionTypeHandler, MetadataHandler, CustomLayerHandler, MetricHandler
+    PredictionTypeHandler, MetadataHandler, CustomLayerHandler
 from code_loader.contract.enums import DataStateEnum, TestingSectionEnum, DataStateType
 from code_loader.contract.exceptions import DatasetScriptException
 from code_loader.contract.responsedataclasses import DatasetIntegParseResult, DatasetTestResultPayload, \
     DatasetPreprocess, DatasetSetup, DatasetInputInstance, DatasetOutputInstance, DatasetMetadataInstance, \
-    VisualizerInstance, PredictionTypeInstance, ModelSetup, CustomLayerInstance, MetricInstance
+    VisualizerInstance, PredictionTypeInstance, ModelSetup, CustomLayerInstance
 from code_loader.leap_binder import global_leap_binder
 from code_loader.utils import get_root_exception_line_number, get_shape
 
@@ -29,15 +29,6 @@ class LeapLoader:
         except Exception as e:
             raise DatasetScriptException(getattr(e, 'message', repr(e))) from e
 
-    @lru_cache()
-    def metric_by_name(self) -> Dict[str, MetricHandler]:
-        self.exec_script()
-        setup = global_leap_binder.setup_container
-        return {
-            metric_handler.name: metric_handler
-            for metric_handler in setup.metrics
-        }
-
     @lru_cache()
     def visualizer_by_name(self) -> Dict[str, VisualizerHandler]:
         self.exec_script()
@@ -211,25 +202,23 @@ class LeapLoader:
         metadata = [DatasetMetadataInstance(name=metadata.name, type=metadata.type)
                     for metadata in setup.metadata]
 
-        visualizers = [
-            VisualizerInstance(visualizer_handler.name, visualizer_handler.type, visualizer_handler.arg_names)
-            for visualizer_handler in setup.visualizers]
+        visualizers = [VisualizerInstance(visualizer_handler.name, visualizer_handler.type, visualizer_handler.arg_names)
+                    for visualizer_handler in setup.visualizers]
 
         custom_loss_names = [custom_loss.name for custom_loss in setup.custom_loss_handlers]
 
         prediction_types = []
         for prediction_type in setup.prediction_types:
-            pred_type_inst = PredictionTypeInstance(prediction_type.name, prediction_type.labels)
+            custom_metrics_names = None
+            if prediction_type.custom_metrics:
+                custom_metrics_names = [custom_metric.__name__ for custom_metric in prediction_type.custom_metrics]
+            pred_type_inst = PredictionTypeInstance(prediction_type.name, prediction_type.labels,
+                                                    prediction_type.metrics, custom_metrics_names)
             prediction_types.append(pred_type_inst)
 
-        metrics = []
-        for metric in setup.metrics:
-            metric_inst = MetricInstance(metric.name, metric.arg_names)
-            metrics.append(metric_inst)
-
         return DatasetSetup(preprocess=dataset_preprocess, inputs=inputs, outputs=ground_truths, metadata=metadata,
                             visualizers=visualizers, prediction_types=prediction_types,
-                            custom_loss_names=custom_loss_names, metrics=metrics)
+                            custom_loss_names=custom_loss_names)
 
     @staticmethod
     def get_model_setup_response() -> ModelSetup:
